@@ -12,13 +12,24 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
+
 from string import Formatter as StringFormatter
+from urllib.parse import urlencode
 
-from six.moves.urllib.parse import urlencode
+from cloudkittyclient import utils
 
 
-class BaseManager(object):
+class HttpDecoratorMeta(type):
+
+    ignore = ('get_url', )
+
+    def __new__(cls, *args, **kwargs):
+        return utils.format_http_errors(HttpDecoratorMeta.ignore)(
+            super(HttpDecoratorMeta, cls).__new__(cls, *args, **kwargs)
+        )
+
+
+class BaseManager(object, metaclass=HttpDecoratorMeta):
     """Base class for Endpoint Manager objects."""
 
     url = ''
